summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorrahulp132022-02-22 01:50:56 +0530
committerrahulp132022-02-22 01:50:56 +0530
commit272bf20219595c3c541797b1045ce9c400ab02d6 (patch)
treea0deeb42b8bfa9af1294b28f4849f92be76ee076 /src
parentab7dd7ed89899e2a17f70262e83437f50f2a924f (diff)
downloadeSim-272bf20219595c3c541797b1045ce9c400ab02d6.tar.gz
eSim-272bf20219595c3c541797b1045ce9c400ab02d6.tar.bz2
eSim-272bf20219595c3c541797b1045ce9c400ab02d6.zip
Added a note and tooltip for Makerchip requirements
Diffstat (limited to 'src')
-rwxr-xr-xsrc/maker/Maker.py21
-rwxr-xr-xsrc/maker/NgVeri.py4
2 files changed, 17 insertions, 8 deletions
diff --git a/src/maker/NgVeri.py b/src/maker/NgVeri.py
index c3c4d07c..c1fbcb4e 100755
--- a/src/maker/NgVeri.py
+++ b/src/maker/NgVeri.py
@@ -226,6 +226,10 @@ class NgVeri(QtWidgets.QWidget):
self.addverilogbutton = QtWidgets.QPushButton(
"Run Verilog to NgSpice Converter")
+ self.addverilogbutton.setToolTip(
+ "Requires internet connection for converting TL-Verilog models"
+ )
+ self.addverilogbutton.setToolTipDuration(5000)
self.optionsgroupbtn.addButton(self.addverilogbutton)
self.addverilogbutton.clicked.connect(self.addverilog)
self.optionsgrid.addWidget(self.addverilogbutton, 0, 1)
diff --git a/src/maker/Maker.py b/src/maker/Maker.py
index 6d97e4d3..9f4263c2 100755
--- a/src/maker/Maker.py
+++ b/src/maker/Maker.py
@@ -224,14 +224,15 @@ class Maker(QtWidgets.QWidget):
if self.verilogfile.split('.')[-1] != "tlv":
reply = QtWidgets.QMessageBox.warning(
None,
- "Do you want to automate top module?",
- "<b>Click on YES if you want top module \
- to be automatically added. \
- NOTE: a .tlv file will be created \
- in the directory of current verilog file\
- and the makerchip will be running on \
- this file. Otherwise click on NO.</b><br/> \
- <b> To not open Makerchip, click CANCEL</b>",
+ "Do you want to automate the top module? ",
+ "<b>Click on YES button if you want the top module \
+ to be added automatically. A .tlv file will be created \
+ in the directory of current verilog file \
+ and the Makerchip IDE will be running on \
+ this file. Otherwise click on NO button. \
+ To not open Makerchip IDE, click on CANCEL button. </b>\
+ <br><br> NOTE: Makerchip IDE requires an active \
+ internet connection and a browser.",
QtWidgets.QMessageBox.Yes
| QtWidgets.QMessageBox.No
| QtWidgets.QMessageBox.Cancel)
@@ -380,6 +381,10 @@ Please check if Verilog File Chosen.")
# self.optionsbox.setLayout(self.optionsgrid)
# self.grid.addWidget(self.creategroup(), 1, 0, 5, 0)
self.runoptions = QtWidgets.QPushButton("Edit in Makerchip")
+ self.runoptions.setToolTip(
+ "Requires internet connection and a browser"
+ )
+ self.runoptions.setToolTipDuration(5000)
self.optionsgroupbtn.addButton(self.runoptions)
self.runoptions.clicked.connect(self.runmakerchip)
self.optionsgrid.addWidget(self.runoptions, 0, 4)